@@ -7,7 +7,7 @@ import os
 from mopidy import config, ext
 
 
-__version__ = '1.0.4'
+__version__ = '1.0.6'
 logger = logging.getLogger(__name__)
 
 
@@ -34,5 +34,5 @@ class Extension(ext.Extension):
         return schema
 
     def setup(self, registry):
-        from mopiqtt.frontend import MQTTFrontend
-        registry.add('frontend', MQTTFrontend)
+        from mopiqtt.frontend import MopiqttFrontend
+        registry.add('frontend', MopiqttFrontend)
